@@ -13,7 +13,7 @@ from irisml.core import JobDescription
 
 logger = logging.getLogger(__name__)
 
-SHARED_MEMORY_SIZE = '8g'
+SHARED_MEMORY_SIZE = '16g'
 
 
 class AMLJobManager:
@@ -160,6 +160,10 @@ class JobEnvironment:
 
     @property
     def dockerfile(self):
+        """Create a dockerfile for AML Run.
+
+        We set LD_LIBRARY_PATH so that tasks can install/load those libs when needed. For example, irisml-tasks-onnx requires those cuda runtimes.
+        """
         label_statement = f'LABEL build-date={datetime.date.today()}' if self._add_docker_build_date else ''
         pip_packages_str = ' '.join([f'"{p}"' for p in self._pip_packages])
         pip_option = f' --extra-index-url {self._extra_index_url}' if self._extra_index_url else ''
@@ -167,9 +171,13 @@ class JobEnvironment:
 RUN apt-get update && apt-get install -y --no-install-recommends python3-pip python3-venv python3.8-dev build-essential && rm -rf /var/lib/apt/lists/*
 RUN python3.8 -m venv /opt/python
 ENV PATH=/opt/python/bin:$PATH
-RUN pip install --disable-pip-version-check --no-cache-dir setuptools wheel
+RUN pip install --no-cache-dir -U pip
+RUN pip install --no-cache-dir setuptools wheel
 {}
-RUN pip install {} {}
+RUN pip install --no-cache-dir {} {}
+ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/cuda_runtime/lib:/opt/python/lib/python3.8/site-packages/nvidia/cublas/lib:$LD_LIBRARY_PATH
+ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/cudnn/lib:/opt/python/lib/python3.8/site-packages/nvidia/curand/lib:$LD_LIBRARY_PATH
+ENV LD_LIBRARY_PATH=/opt/python/lib/python3.8/site-packages/nvidia/nvtx/lib:/opt/python/lib/python3.8/site-packages/nvidia/cufft/lib:$LD_LIBRARY_PATH
 """.format(label_statement, pip_packages_str, pip_option)
 
     def _add_standard_packages(self, custom_packages):
